==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/people_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::PeopleController < CoreModelsController
    # GET /people_and_companies/people
    # GET /people_and_companies/people.json
    def index
      @people_and_companies_people = PeopleAndCompanies::Person.order("id")

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_people }
      end
    end

    # GET /people_and_companies/people/1
    # GET /people_and_companies/people/1.json
    def show
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_person }
      end
    end

    # GET /people_and_companies/people/new
    # GET /people_and_companies/people/new.json
    def new
      @people_and_companies_person = PeopleAndCompanies::Person.new
      @people_and_companies_person.build_person_photo
      @people_and_companies_person.person_photo.build_photo

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_person }
      end
    end

    # GET /people_and_companies/people/1/edit
    def edit
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])

      if @people_and_companies_person.photo.nil?
        @people_and_companies_person.build_person_photo
        @people_and_companies_person.person_photo.build_photo
      end
    end

    # POST /people_and_companies/people
    # POST /people_and_companies/people.json
    def create
      @people_and_companies_person = PeopleAndCompanies::Person.new(params[:people_and_companies_person])

      respond_to do |format|
        if @people_and_companies_person.save
          format.html { redirect_to @people_and_companies_person, :notice => 'Person was successfully created.' }
          format.json { render :json => @people_and_companies_person, :status => :created, :location => @people_and_companies_person }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_person.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/people/1
    # PUT /people_and_companies/people/1.json
    def update
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])

      respond_to do |format|
        if @people_and_companies_person.update_attributes(params[:people_and_companies_person])
          format.html { redirect_to @people_and_companies_person, :notice => 'Person was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_person.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/people/1
    # DELETE /people_and_companies/people/1.json
    def destroy
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])
      @people_and_companies_person.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_people_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/people_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::PeopleController < CoreModelsController
    # GET /people_and_companies/people
    # GET /people_and_companies/people.json
    def index
      @people_and_companies_people = PeopleAndCompanies::Person.order("id")

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_people }
      end
    end

    # GET /people_and_companies/people/1
    # GET /people_and_companies/people/1.json
    def show
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_person }
      end
    end

    # GET /people_and_companies/people/new
    # GET /people_and_companies/people/new.json
    def new
      @people_and_companies_person = PeopleAndCompanies::Person.new
      @people_and_companies_person.build_person_photo
      @people_and_companies_person.person_photo.build_photo

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_person }
      end
    end

    # GET /people_and_companies/people/1/edit
    def edit
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])

      if @people_and_companies_person.photo.nil?
        @people_and_companies_person.build_person_photo
        @people_and_companies_person.person_photo.build_photo
      end
    end

    # POST /people_and_companies/people
    # POST /people_and_companies/people.json
    def create
      @people_and_companies_person = PeopleAndCompanies::Person.new(params[:people_and_companies_person])

      respond_to do |format|
        if @people_and_companies_person.save
          format.html { redirect_to @people_and_companies_person, :notice => 'Person was successfully created.' }
          format.json { render :json => @people_and_companies_person, :status => :created, :location => @people_and_companies_person }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_person.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/people/1
    # PUT /people_and_companies/people/1.json
    def update
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])

      respond_to do |format|
        if @people_and_companies_person.update(params[:people_and_companies_person])
          format.html { redirect_to @people_and_companies_person, :notice => 'Person was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_person.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/people/1
    # DELETE /people_and_companies/people/1.json
    def destroy
      @people_and_companies_person = PeopleAndCompanies::Person.find(params[:id])
      @people_and_companies_person.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_people_url }
        format.json { head :no_content }
      end
    end
  end
end
